pub struct SessionJournal {
pub entries: Vec<SessionEntry>,
pub leaf_id: Option<EntryId>,
pub schema_version: u32,
pub spawn_depth: u32,
}Fields
entries: Vec<SessionEntry>leaf_id: Option<EntryId>schema_version: u32spawn_depth: u32Implementations
Sourceimpl SessionJournal
impl SessionJournal
pub fn new() -> Self
pub fn with_spawn_depth(depth: u32) -> Self
pub fn append(&mut self, kind: SessionEntryKind) -> EntryId
pub fn append_message(&mut self, message: Message) -> EntryId
pub fn append_compaction( &mut self, summary: String, tokens_before: Option<u64>, tokens_after: Option<u64>, model: Option<String>, ) -> EntryId
pub fn append_branch_summary( &mut self, branch_id: String, summary: String, parent_branch_id: Option<String>, ) -> EntryId
pub fn branch_to(&mut self, entry_id: &str) -> Result<(), String>
pub fn fork_from(&self, from_entry_id: Option<&str>) -> Result<Self, String>
pub fn index(&self) -> HashMap<&str, &SessionEntry>
pub fn children_of(&self, parent_id: Option<&str>) -> Vec<&SessionEntry>
pub fn contains(&self, entry_id: &str) -> bool
pub fn leaf(&self) -> Option<&SessionEntry>
pub fn root_to_leaf(&self) -> Vec<&SessionEntry>
pub fn active_messages(&self, include_system: bool) -> Vec<Message>
pub fn leaves(&self) -> Vec<&SessionEntry>
pub fn is_empty(&self) -> bool
pub fn len(&self) -> usize
pub fn validate(&self) -> Result<(), String>
pub fn from_messages(messages: Vec<Message>, spawn_depth: u32) -> Self
pub fn to_messages(&self) -> Vec<Message>
Sourcepub fn rebranch_active_messages(&mut self, messages: &[Message])
pub fn rebranch_active_messages(&mut self, messages: &[Message])
Make messages the active projection without rewriting the journal.
The existing active branch remains as evidence. We reuse its longest unchanged prefix, then append the repaired suffix as a sibling branch.